# Generated by Django 2.2.3 on 2019-07-21 18:23

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Name",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("full", models.CharField(max_length=100, verbose_name="Full name")),
                (
                    "title",
                    models.CharField(blank=True, max_length=100, verbose_name="Title"),
                ),
                (
                    "first",
                    models.CharField(
                        blank=True, max_length=100, verbose_name="First name"
                    ),
                ),
                (
                    "last",
                    models.CharField(
                        blank=True, max_length=100, verbose_name="Last name"
                    ),
                ),
                (
                    "middle",
                    models.CharField(
                        blank=True, max_length=100, verbose_name="Middle name"
                    ),
                ),
                (
                    "nickname",
                    models.CharField(
                        blank=True, max_length=100, verbose_name="Nickname"
                    ),
                ),
                (
                    "suffix",
                    models.CharField(blank=True, max_length=100, verbose_name="Suffix"),
                ),
            ],
            options={"abstract": False},
        )
    ]
